=============
Ironic Policy
=============

The following is a sample Ironic policy file, autogenerated from Ironic when
this documentation is built. To prevent conflicts, ensure your version of
Ironic aligns with the version of this documentation.

The sample policy can also be downloaded as a :download:`file
</_static/ironic.policy.yaml.sample>`.

.. literalinclude:: /_static/ironic.policy.yaml.sample
